from os import system

class Execute:

    def Pop(self):
        system(self)

    class Path():
        def Pop(self):
            self = self+'\\__init__.py'
            var = False
            try:
                a = open(self,'at')
            except:
                var = False

            else:
                var = True
            finally:
                a.close()
                
            if var == True:
                system(self)
            else:
                print('Não Foi Possivel Executa O Caminho Defindo')





class Write():
    class Variable():
        class Path():
            class Str():
                def Pop(self,nome_da_variavel,conteudo_da_variavel):
                    self = self +'\\__init__.py'
                    ide = nome_da_variavel
                    metod = str(f"'{conteudo_da_variavel}'")
                    variable = f'{ide} = {metod}'
                    try:
                        with open(self,'at') as tipagem:
                            tipagem.write(f'{variable}\n')
                    except:
                        print('Não achamos nada no ponto definido')
                

            class Int():
                def Pop(self,nome_da_variavel,conteudo_da_variavel):
                    self = self + '\\__init__.py'
                    ide = nome_da_variavel
                    metod = int(conteudo_da_variavel)
                    variable = f'{ide} = {metod}'
                    try:
                        with open(self,'at') as tipagem:
                            tipagem.write(f'{variable}\n')
                    except:
                        print('Não achamos nada no ponto definido')
              

            class Float():
                def Pop(self,nome_da_variavel,conteudo_da_variavel):
                    self = self +'\\__init__.py'
                    ide = nome_da_variavel
                    metod = float(conteudo_da_variavel)
                    variable = f'{ide} = {metod}'
                    try:
                        with open(self,'at') as tipagem:
                            tipagem.write(f'{variable}\n')
                    except:
                        print('Não achamos nada no ponto definido')
                    
            class Bool():
                
                def Pop(self,nome_da_variavel,conteudo_da_variavel):
                    self = self +'\\__init__.py'
                    ide = nome_da_variavel
                    metod = conteudo_da_variavel
                    if metod == True or metod == False:
                        variable = f'{ide} = {metod}'
                        try:
                            with open(self,'at') as tipagem:
                                tipagem.write(f'{variable}\n')
                        except:
                            print('Não achamos nada no ponto definido')
                    
                    else:
                        print('É Permitido Apenas Numero Boll')











        class Str():
            def Pop(self,nome_da_variavel,conteudo_da_variavel):
                ide = nome_da_variavel
                metod = str(f"'{conteudo_da_variavel}'")
                variable = f'{ide} = {metod}'
                try:
                    with open(self,'at') as tipagem:
                        tipagem.write(f'{variable}\n')
                except:
                    print('Não achamos nada no ponto definido')
                

        class Int():
            def Pop(self,nome_da_variavel,conteudo_da_variavel):
                ide = nome_da_variavel
                metod = int(conteudo_da_variavel)
                variable = f'{ide} = {metod}'
                try:
                    with open(self,'at') as tipagem:
                        tipagem.write(f'{variable}\n')
                except:
                    print('Não achamos nada no ponto definido')
              

        class Float():
            def Pop(self,nome_da_variavel,conteudo_da_variavel):
                ide = nome_da_variavel
                metod = float(conteudo_da_variavel)
                variable = f'{ide} = {metod}'
                try:
                    with open(self,'at') as tipagem:
                        tipagem.write(f'{variable}\n')
                except:
                    print('Não achamos nada no ponto definido')
                
        class Bool():
            def Pop(self,nome_da_variavel,conteudo_da_variavel):
                ide = nome_da_variavel
                metod = conteudo_da_variavel

                if metod == True or metod == False:
                    variable = f'{ide} = {metod}'
                    try:
                        with open(self,'at') as tipagem:
                            tipagem.write(f'{variable}\n')
                    except:
                        print('Não achamos nada no ponto definido')
                   
                else:
                    print('É Permitido Apenas Numero Boll')
    class Pop():
        def Print(self,menssagem):
            menssagem = f"'{menssagem}'"
            with open(self,'at') as Dd:
                Dd.write(f'print({menssagem})')


from os import system  
class Delete:
    class Path():
        def Pop(self):
            system(f'del {self}\\__init__.py ')
            system(f'rmdir {self}')

    def Pop(self):
        system(f'del {self}')





class Connect:
    class Path:
        def Pop(self):
            init = f'{self}\\__init__.py'
            try:
                sistema = open(init,'at')
            except:
                print("Não Encontramos nenhum arquivo no caminho definido")
            else:
                return init

    def Pop(self):
        try:
            sistema = open(self,'at')
        except:
            print("Não Encontramos nenhum arquivo no caminho definido")
        else:
            return self
        
    


from os import mkdir

class Create():
    class Path():
        def Pop(self):
            """
            Ciar Uma Pasta Com Armazen de 
            Dados Dentro, diferente do Pop Normal
            Este Dados sé Você Estiver Desenvolvendo
            Algum Tipo de Aplicação Que Será Salva como
            Exe esta função e melhor pois será posivel ler 
            pega os dados Da Aplicação Aplicação ja no pop normal
            so é possivel peda os dados da aplicação executando como script

            self = "Nome Da Pasta a ser Criada"
            """

            try:
                mkdir(self)
            except:
                pass

            init = f'{self}\\__init__.py'

            try:
                dado = open(init,'at')
            except:
                dado = open(init,'wt+')
            else:
                print('Ja Foi Criada A Pasta Definida')
            finally:
                dado.close()
            

            
        


    def Pop(self):

        """
        Cria Um Armazen Para Dados
        Estes Dados Jamais Serão Perdidos
        Mais se você estiver criando uma aplicação
        Que será salva como exe esta função não é recomendada
        Pois Não será Possivel Pega os Dados apenas será possivel
        Pega Os Dados Rodando Como Script

        self = 'Nome Do Arquivo a Ser Criado'

        lenbrando não esqueça de adiciona a estenção .py :)
    
        """

        try:
            dado = open(self,'at')
        except:
            dado = open(self,'wt+')
        else:
            print('este arquivo ja foi criado')
        finally:
            dado.close()
        

    






from BankPy.Create import *
from BankPy.Connect import *
from BankPy.Variables import *
from BankPy.Execute import *
from BankPy.Delete import *
from BankPy.Howmate import *
from BankPy import BankPy



print('''Obrigado Por Utiliza BankPy - v 1.0.5
Update Da Versão 1.0.4 Esta Versão Esta Em Beta''')

